==> haskell-digits-0.3.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-By65ClVfWD13dVZA311EcW
key:                  digits-0.3.2-By65ClVfWD13dVZA311EcW
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  1cb2021af4fec7a3a3dab7b55b2d4158
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-By65ClVfWD13dVZA311EcW
depends:
    QuickCheck-2.15.0.1-JsWG6I4IuTa3MyVRCp1l9o base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digits-0.3.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 digits
version:              0.3.2
visibility:           public
id:                   digits-0.3.2-92c3iccxHQpJmCMbAdc14s
key:                  digits-0.3.2-92c3iccxHQpJmCMbAdc14s
license:              BSD-3-Clause
copyright:            (c) 2009-2025 Henry Bucklow, (c) 2016 Charlie Harvey
maintainer:           opensource@elsie.org.uk
author:               Henry Bucklow
synopsis:             Converts integers to lists of digits and back.
description:
    Converts integers to lists of digits and back. Supports arbitrary bases.

category:             Data
abi:                  8675a754b8436995e4a743c13fc84111
exposed:              True
exposed-modules:      Data.Digits
import-dirs:          /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/digits-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-digits
hs-libraries:         HSdigits-0.3.2-92c3iccxHQpJmCMbAdc14s
depends:
    QuickCheck-2.15.0.1-3qjshr9DgdW3qKiQXq7Lfs base-4.18.2.1

haddock-interfaces:   /usr/share/doc/haskell-digits/html/digits.haddock
haddock-html:         /usr/share/doc/haskell-digits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
